@@ -383,8 +383,14 @@ def resample_summary_to_daily(para_combination, folder=''):
     sec_profile = para_combination['sec_profile']
 
     if sectype == 'FUT':
+        for key in sec_profile:
+            if 'margin_req' in key:
+                sec_profile['margin_req'] = sec_profile.pop(key)
+                break
+
         margin_req = sec_profile['margin_req']
         multiplier = sec_profile['multiplier']
+
     elif sectype == 'STK':
         multiplier = 1
 
